@@ -4,6 +4,11 @@ Demonstrates high-speed parallel token generation.
 """
 import torch
 from transformers import AutoTokenizer
+import sys
+import os
+
+# Add project root to sys.path to allow importing parallel_llm from source
+sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
 
 # Updated imports
 from parallel_llm.core import DiffusionTransformer, ModelConfig
