@@ -8,6 +8,10 @@ import torch.distributed as dist
 from torch.utils.data import DataLoader, DistributedSampler
 from transformers import AutoTokenizer
 from datasets import load_dataset
+import sys
+
+# Add project root to sys.path to allow importing parallel_llm from source
+sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
 
 # Updated imports for v0.4.0 structure
 from parallel_llm.core import DiffusionTransformer, ModelConfig
